<?php

namespace BeycanPress\Story\Integrations;

use \BeycanPress\Story\Traits\Helpers;
/**
 * BP Story category image integration
 */
class CategoryImage
{

    use Helpers;

    /**
     * Class construct
     * @return void
     */
    public function __construct()
    {
        if (is_admin()) {
            add_action('category_add_form_fields', array($this, 'addInputCategoryAddPage'));
            add_action('category_edit_form_fields', array($this, 'addInputCategoryEditPage'), 10, 1);
            add_action('manage_edit-category_columns', array($this, 'showImageInCategoryList'), 10, 1);
            add_action('manage_category_custom_column', array($this, 'showImageInCategoryListNext'), 10, 3);
            add_action('edited_category', array($this, 'saveCategoryImage'), 10, 1);  
            add_action('create_category', array($this, 'saveCategoryImage'), 10, 1);
        }
    }

    /**
     * Show in the add new category field
     * @return void
     */
    public function addInputCategoryAddPage()
    {
        echo $this->view('category-image/add-input');
    }

    /**
     * Show in the edit category field
     * @param object $term
     * @return void
     */
    public function addInputCategoryEditPage($term)
    {
        $imageURL = get_option("taxonomy_".$term->term_id."_image");
        echo $this->view('category-image/edit-input', array('imageURL' => $imageURL));
    }

    /**
     * @param integer $termId
     * @return void
     */
    public function saveCategoryImage($termId) 
    {
        if (isset($_POST['bpstory_catgory_image_url'])){
            $imageURL = esc_url_raw($_POST['bpstory_catgory_image_url']);
            update_option("taxonomy_".$termId."_image", $imageURL);
        }
    }    

    /**
     * add column for image
     * @param array $defaults
     * @return array
     */
    public function showImageInCategoryList($defaults)
    {
        $cb = $defaults["cb"];
        array_shift($defaults);
        return array("cb" => $cb, "bpstory_category_image" => esc_html__('Image:', 'bpstory')) + $defaults;
    }
    
    /**
     * Add thumbnail image to the category list
     * @param string $par
     * @param string $col col name
     * @param integer $catId current category id
     * @return void
     */
    public function showImageInCategoryListNext($par, $col, $catId)
    {
        if($col == "bpstory_category_image") {
            $imageURL = get_option( 'taxonomy_'.$catId.'_image' );
            if ($imageURL) {
                return '<img src="' . esc_url($imageURL) . '" width="50" height="50" alt="'.esc_html__('Category image:', 'bpstory').'">';
            } else {
                return '<img src="' . esc_url($this->setting('default_category_image')) . '" width="50" height="50" alt="'.esc_html__('Category image:', 'bpstory').'">';
            }
        }
    }

}