<?php

namespace BeycanPress\Story\Integrations;

use \Elementor\Widget_Base;
use \Elementor\Controls_Manager;
use \BeycanPress\Story\Traits\Helpers;

/**
 * Elementor short code selector
 */
class Elementor extends Widget_Base
{
    use Helpers;

	/**
	 * Retrieve the widget name.
	 *
	 * @since 2.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bpstory';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 2.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__('BP Story', 'bpstory');
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 2.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-image-bold';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 2.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return ['general'];
	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 2.0.0
	 *
	 * @access protected
	 */
	protected function _register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => esc_html__('Select stories shortcode', 'bpstory'),
			]
		);

		$this->add_control(
			'storiesShortcode',
			[
				'label'       => esc_html__('Title', 'bpstory'),
				'type'        => Controls_Manager::SELECT,
				'default'     => 'null',
				'options'     => array(
					'[bpstory-user-stories]'    => esc_html__('User stories', 'bpstory'),
					'[bpstory-admin-stories]'   => esc_html__('Admin stories', 'bpstory'),
					'[bpstory-post-stories]'    => esc_html__('Post stories', 'bpstory'),
					'[bpstory-product-stories]' => esc_html__('Product creator', 'bpstory'),
				)
			]
		);

		$this->end_controls_section();
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 2.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		echo $this->get_settings_for_display('stories');
	}

	/**
	 * Render the widget output in the editor.
	 *
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 *
	 * @since 2.0.0
	 *
	 * @access protected
	 */
	protected function _content_template() {
		?> {{{ settings.storiesShortcode }}} <?php
	}
}
