<?php

namespace BeycanPress\Story;

use \Elementor\Plugin;

class RegisterIntegrations
{
    use Traits\Helpers;

    public function __construct()
    {   
        // Register category image integration
        new Integrations\CategoryImage;
        new Integrations\MetaBoxes;

        // Register BuddyPress integration
        if (function_exists('buddypress') && $this->setting('buddypress_my_stories')) {
            new Integrations\BuddyPress;
        } 

        // Register bbPress integration
        if (class_exists('bbPress') && $this->setting('bbpress_my_stories')) {
            new Integrations\BBPress;
        }

        // Register Elementor integration
        if (defined('ELEMENTOR_VERSION')) {
            add_action( 'elementor/widgets/widgets_registered', function(){
                Plugin::instance()->widgets_manager->register_widget_type(new Integrations\Elementor());
            });
        }

        // Register Gutenberg block
        add_action('enqueue_block_editor_assets', function() {
            wp_enqueue_script(
                'bpstory_gutenberg',
                $this->url . 'assets/js/gutenberg.min.js',
                array('wp-blocks', 'wp-editor', 'jquery'),
                $this->version
            );
            wp_localize_script(
                'bpstory_gutenberg',
                'BPStory',
                Loader::jsData()
            );
        });    

        // Register TinyMCE button
        add_action('admin_head', function() {
            add_filter('mce_external_plugins', function($pluginArray) {
                $pluginArray['bpstory'] = $this->url . 'assets/js/tinymce.min.js';
                return $pluginArray;
            });
            add_filter('mce_buttons', function($buttons) {
                array_push($buttons, 'bpstory');
                return $buttons;
            });
        });
    }
}