<?php

namespace BeycanPress\Story\StoryTypes;

use \BeycanPress\Story\Helpers\Response;
use \BeycanPress\Story\Traits\Helpers;

/**
 * Everything about post stories is here
 */
class PostStories
{
    use Helpers;

    /**
     * Register post stories short code
     */
    public function __construct()
    {
        if (is_admin()) {
            // Ajax
            $this->ajaxAction('getPostStoriesList');
        } else {
            add_action('init', function(){
                add_shortcode('bpstory-post-stories', array($this, 'init'));
            });
        }
    }

    public function init()
    {
        $categories = get_terms(array('taxonomy' => 'category'));
        if ($categories) {
			$categories = array_values($categories);
			$category = array_shift($categories);
			$categoryLink = get_category_link($category->term_id);
			$storyBoxRedirectURL = str_ireplace([
				$category->slug . '/',
				$category->slug
			], '', $categoryLink);
		} else {
			$storyBoxRedirectURL = null;
		}

        return $this->view('bpstory-js', [
            'id' => 'post-stories',
            'options' => [
                "getStoriesParameter" => "getPostStoriesList",
                "storyBoxRedirectURL" => $storyBoxRedirectURL
            ]
        ]);
    }

    protected function getStoryBoxes()
    {
        $storyBoxes = [];
        foreach (get_terms(array('taxonomy' => 'category')) as $key => $value) {

            $storyItems = [];

            if (0 !== $value->count && 0 === $value->parent) {
                $args = array(
                    'post_type'      => 'post',
                    'paged'          => 1,
                    'posts_per_page' => $this->setting('story_limit'),
                    'post_status'    => 'publish',
                    'order'          => 'ASC',
                    'cat'            => $value->term_id,
                    'meta_query'     => array(
                        array(
                            'key' => 'bpstory_story_visibility',
                            'value' => 'on',
                        )
                    )
                );

                $postList = new \WP_Query($args);

                if ($postList->have_posts()) :

                    foreach ($postList->posts as $key => $post) {

                        $mediaURL = get_post_meta($post->ID, 'bpstory_media_url', true);

                        if (!$mediaURL || $mediaURL == '') {
                            $mediaURL = get_the_post_thumbnail_url($post->ID);
                            if (!$mediaURL) {
                                $mediaURL = $this->setting('default_media_url');
                            }
                        }

                        $storyItems[] = [
                            'storyId' => $post->ID,
                            'mediaURL' => $mediaURL,
                            'externalURL' => get_the_permalink($post->ID),
                            'createdAt' => $post->post_date,
                            'publishTime' => $this->dateToTimeAgo($post->post_date),
                        ];

                    }

                    $storyBoxImage = get_option("taxonomy_".$value->term_id."_image");
                    if (!isset($storyBoxImage) || empty($storyBoxImage)) {
                        $storyBoxImage = $this->setting('default_category_image');
                    }

                    $lastStory = (object) end($storyItems);
                    $storyBoxes[] = array(
                        'storyBox'             => $value->slug,
                        'storyBoxImage'        => $storyBoxImage,
                        'lastStoryCreatedAt'   => strtotime($lastStory->createdAt),
                        'lastStoryPublishTime' => $lastStory->publishTime,
                        'storyItems'           => $storyItems,
                    );

            endif;
            }
        }

        usort($storyBoxes, function($a, $b) {
            return $a['lastStoryCreatedAt'] < $b['lastStoryCreatedAt'];
        });

        return $storyBoxes;
    }

    public function getPostStoriesList()
    {
        $storyBoxes = $this->getStoryBoxes();
        if (count($storyBoxes) == 0) {
            Response::success(esc_html__('No story found.', 'bpstory'));
        }

        Response::success(null, $this->getStoryBoxes());
    }

}