<?php

namespace BeycanPress\Story\StoryTypes;

use \BeycanPress\Story\Helpers\Response;
use \BeycanPress\Story\Traits\Helpers;

/**
 * Everything product user stories is here
 */
class ProductStories
{
    use Helpers;

    /**
     * Register product stories short code
     */
    public function __construct()
    { 
        add_action('plugins_loaded', function(){
            if (function_exists('WC')) {
                if (is_admin()) {
                    // Ajax
                    $this->ajaxAction('getProductStoriesList');
                } else {
                    add_action('init', function(){
                        add_shortcode('bpstory-product-stories', array($this, 'init'));
                    });
                }
            }
        });
    }

    public function init()
    {
        $categories = get_terms(array('taxonomy' => 'product_cat'));
        if ($categories) {
			$categories = array_values($categories);
			$category = array_shift($categories);
			$categoryLink = get_category_link($category->term_id);
			$storyBoxRedirectURL = str_ireplace([
				$category->slug . '/',
				$category->slug
			], '', $categoryLink);
		} else {
			$storyBoxRedirectURL = null;
		}

        return $this->view('bpstory-js', [
            'id' => 'product-stories',
            'options' => [
                "getStoriesParameter" => "getProductStoriesList",
                "storyBoxRedirectURL" => $storyBoxRedirectURL
            ]
        ]);
    }

    protected function getStoryBoxes()
    {
        $storyBoxes = [];
        foreach (get_terms(array('taxonomy' => 'product_cat')) as $key => $value) {
            if (0 !== $value->count && 0 === $value->parent) {
                
                $storyItems = [];

                $args = array(
                    'post_type'      => 'product',
                    'paged'          => 1,
                    'posts_per_page' => $this->setting('story_limit'),
                    'post_status'    => 'publish',
                    'order'          => 'ASC',
                    'product_cat'    => $value->slug,
                    'meta_query'     => array(
                        array(
                            'key' => 'bpstory_story_visibility',
                            'value' => 'on',
                        )
                    )
                );
    
                $postList = new \WP_Query($args);
    
                if ($postList->have_posts()) :
    
                    foreach ($postList->posts as $key => $post) {
    
                        $mediaURL = get_post_meta($post->ID, 'bpstory_media_url', true);
    
                        if (!$mediaURL || $mediaURL == '') {
                            $mediaURL = get_the_post_thumbnail_url($post->ID);
                            if (!$mediaURL) {
                                $mediaURL = $this->setting('default_media_url');
                            }
                        }
    
                        $storyItems[] = [
                            'storyId' => $post->ID,
                            'mediaURL' => $mediaURL,
                            'externalURL' => get_the_permalink($post->ID),
                            'createdAt' => $post->post_date,
                            'publishTime' => $this->dateToTimeAgo($post->post_date),
                        ];
    
                    }
                    
                    $thumbnailId = get_term_meta($value->term_id, 'thumbnail_id', true); 
                    $storyBoxImage = wp_get_attachment_url($thumbnailId); 
                    if (!isset($storyBoxImage) || empty($storyBoxImage)) {
                        $storyBoxImage = $this->setting('default_category_image');
                    }
    
                    $lastStory = (object) end($storyItems);
                    $storyBoxes[] = array(
                        'storyBox'             => $value->slug,
                        'storyBoxImage'        => $storyBoxImage,
                        'lastStoryCreatedAt'   => strtotime($lastStory->createdAt),
                        'lastStoryPublishTime' => $lastStory->publishTime,
                        'storyItems'           => $storyItems,
                    );
    
                endif;
            }
        }

        usort($storyBoxes, function($a, $b) {
            return $a['lastStoryCreatedAt'] < $b['lastStoryCreatedAt'];
        });

        return $storyBoxes;
    }

    public function getProductStoriesList()
    {
        $storyBoxes = $this->getStoryBoxes();
        if (count($storyBoxes) == 0) {
            Response::success(esc_html__('No story found.', 'bpstory'));
        }

        Response::success(null, $this->getStoryBoxes());
    }

}